/* SPDX-License-Identifier: GPL-3.0-or-later */
/* Copyright (C) 2021 KikooDX */

#include "filepaths.h"
#include "input.h"
#include "levelselection.h"
#include "util.h"
#include <gint/keyboard.h>

/* Return 1 if game state should change. */
int
levelselection_update(struct LevelSelection *levelselection, struct Input input)
{
	const int sign_transition_speed =
	    sign(levelselection->transition_speed);
	/* update transition state */
	if (levelselection->transition_speed != 0.0)
		levelselection->transition += levelselection->transition_speed;
	/* end transition if necessary */
	if (levelselection->transition * -sign_transition_speed <
	    levelselection->transition_speed * -sign_transition_speed) {
		levelselection->visual_cursor = levelselection->pack_cursor;
		levelselection->transition = 0.0;
		levelselection->transition_speed = 0.0;
	}

	if (levelselection->transition == 0.0) {
		/* decrease selected pack id */
		if (input.keystates[K_LEFT] &&
		    levelselection->pack_cursor > 0) {
			levelselection->visual_cursor =
			    levelselection->pack_cursor;
			levelselection->pack_cursor -= 1;
			levelselection->transition = -1.0;
			levelselection->transition_speed =
			    PACKBOX_TRANSITION_SPEED;
		}
		/* increase selected pack id */
		if (input.keystates[K_RIGHT] &&
		    levelselection->pack_cursor < PACK_COUNT - 1) {
			levelselection->visual_cursor =
			    levelselection->pack_cursor;
			levelselection->pack_cursor += 1;
			levelselection->transition = 1.0;
			levelselection->transition_speed =
			    -PACKBOX_TRANSITION_SPEED;
		}
	}
	/* confirm */
	if (input.keystates[K_A] == KS_PRESS) {
		levelselection->visual_cursor = levelselection->pack_cursor;
		levelselection->transition = 0.0;
		levelselection->transition_speed = 0.0;
		return 1;
	}

	return 0;
}
